@@ -74,10 +74,10 @@ class Oauth2:
                 code=code, scopes=[self._scope], redirect_uri=redirect_uri
             )
             expires_in = tokens_result.get("expires_in")
-            expiration_date = datetime.datetime.now() + datetime.timedelta(
-                seconds=expires_in - 60
-            )
-            print("Access token expiration date:", expiration_date)
+            expiration_date = datetime.datetime.now(
+                datetime.timezone.utc
+            ) + datetime.timedelta(seconds=expires_in - 60)
+            print("Access token expiration date (UTC):", expiration_date)
 
             # Set expiration date in the session
             flask.session["expiration_date"] = expiration_date
@@ -126,8 +126,8 @@ class Oauth2:
 
     def check_and_set_token_expiry(self) -> None:
         if flask.session.get("access_token"):
-            expiration_date = flask.session.get("expiration_date")
-            current_date = datetime.datetime.now()
+            expiration_date = flask.session["expiration_date"]
+            current_date = datetime.datetime.now(datetime.timezone.utc)
             if current_date > expiration_date:
                 # Access token has expired
                 print("Access token has expired.")
@@ -137,10 +137,10 @@ class Oauth2:
                     scopes=[self._scope], account=self._accounts[0]
                 )
                 expires_in = renewed_tokens_result.get("expires_in")
-                new_expiration_date = datetime.datetime.now() + datetime.timedelta(
-                    seconds=expires_in - 60
-                )
-                print("New access token expiration date:", new_expiration_date)
+                new_expiration_date = datetime.datetime.now(
+                    datetime.timezone.utc
+                ) + datetime.timedelta(seconds=expires_in - 60)
+                print("New access token expiration date (UTC):", new_expiration_date)
 
                 # Set new expiration date in the session
                 flask.session["expiration_date"] = new_expiration_date
