@@ -2,7 +2,7 @@ from pathlib import Path
 from typing import List
 
 import pandas as pd
-import dash_table
+from dash import dash_table
 
 from .. import WebvizPluginABC
 from ..webviz_store import webvizstore
@@ -48,7 +48,9 @@ If feature is requested, the data could also come from a database.
     def layout(self) -> dash_table.DataTable:
         return dash_table.DataTable(
             columns=[{"name": i, "id": i} for i in self.df.columns],
-            data=self.df.to_dict("records"),
+            data=self.df.to_dict(  # PyCQA/pylint#4577 # pylint: disable=no-member
+                "records"
+            ),
             sort_action="native" if self.sorting else "none",
             filter_action="native" if self.filtering else "none",
             page_action="native" if self.pagination else "none",
