@@ -1,6 +1,6 @@
 from pathlib import Path
 
-import dash_html_components as html
+from dash import html
 
 from .. import WebvizPluginABC
 from ..webviz_assets import WEBVIZ_ASSETS
